pub struct CreateV1 {
pub create_v1_args: CreateV1Args,
}Fields
create_v1_args: CreateV1ArgsTrait Implementations
Sourceimpl ArrangeAccounts for CreateV1
impl ArrangeAccounts for CreateV1
type ArrangedAccounts = CreateV1InstructionAccounts
fn arrange_accounts(accounts: &[AccountMeta]) -> Option<Self::ArrangedAccounts>
Sourceimpl BorshDeserialize for CreateV1where
CreateV1Args: BorshDeserialize,
impl BorshDeserialize for CreateV1where
CreateV1Args: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl CarbonDeserialize for CreateV1
impl CarbonDeserialize for CreateV1
fn deserialize(data: &[u8]) -> Option<Self>
Sourceimpl<'de> Deserialize<'de> for CreateV1
impl<'de> Deserialize<'de> for CreateV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CreateV1
impl StructuralPartialEq for CreateV1